Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(65)

Unified Diff: third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h

Issue 2150973002: Remove threading primitives from ParseHTMLOnMainThread (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2785
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h
diff --git a/third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h b/third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h
index 3ba0b5e6f566e5b4fe8219e8f40a57705ea320dc..63f8df540d8ba0a7db95b9ecf945e44df4d2db64 100644
--- a/third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h
+++ b/third_party/WebKit/Source/core/html/parser/HTMLDocumentParser.h
@@ -188,10 +188,12 @@ private:
Asynchronous,
};
- // Setting |sync| to true will just call the closure. Note, this method is
- // completely temporary as we need to maintain both threading
- // implementations until the ParseHTMLOnMainThread experiment finishes.
- void postTaskToLookaheadParser(std::unique_ptr<CrossThreadClosure>, LookaheadParserTaskSynchrony = Asynchronous);
+ // Setting |synchronyPolicy| to Synchronous will just call the function
+ // with the given parameters. Note, this method is completely temporary
+ // as we need to maintain both threading implementations until the
+ // ParseHTMLOnMainThread experiment finishes.
+ template <typename FunctionType, typename... Ps>
+ void postTaskToLookaheadParser(LookaheadParserTaskSynchrony synchronyPolicy, FunctionType, Ps&&... parameters);
HTMLToken& token() { return *m_token; }

Powered by Google App Engine
This is Rietveld 408576698